/*
This is the code for the wood clock.

Set the time in the lines 72-78.
Adjust the brightness in the lines 43-53.
Adjust the day/night switch parameters in the lines 55,56.
Change 12/24 hour format in the line 111 (default 24 hour).

LED numbers:

    55 54      41 40            25 24      11 10
  56     53  42     39        26     23  12     9 
  57     52  43     38   29   27     22  13     8
    50 51      36 37            20 21      6  7 
  49     44  35     30   28   19     14  5      0
  48     45  34     31        18     15  4      1
    47 46      33 32            17 16      3  2 
          
*/

#include "RTClib.h"
#include <FastLED.h>
RTC_DS3231 rtc;
char daysOfTheWeek[7][12] = {"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"};
#define LED_PIN     7
#define NUM_LEDS    58
CRGB leds[NUM_LEDS];
void off();
void number(int stelle, int ziffer);

int m = 0;
int h = 0;
int mv = 0;
int mh = 0;
int hv = 0;
int hh = 0;
int red = 0;
int green = 0;
int blue = 0;
int z = 1;
int messwert = 0; 

//*****brightness 0-255*****brightness 0-255*****brightness 0-255*****brightness 0-255*****brightness 0-255
int start_blue = 0;    //start sequence 255max
int start_green = 100; //start sequence 255max
int start_red = 255;   //start sequence 255max
int day_blue = 0;      //main brightness 255max
int day_green = 120;   //main brightness 255max
int day_red = 240;     //main brightness 255max
int night_blue = 0;    //night brightness 255max
int night_green = 0; //night brightness 255max
int night_red = 7;   //night brightness 255max
//*****brightness 0-255*****brightness 0-255*****brightness 0-255*****brightness 0-255*****brightness 0-255

int switch_to_night = 5; //Adjust at whitch brightness level the clock gets dark
int switch_to_day = 15;  //Adjust at whitch brightness level the clock gets bright

void setup () {

#ifndef ESP8266
  while (!Serial); // wait for serial port to connect. Needed for native USB
#endif
  if (! rtc.begin()) {
    Serial.println("Couldn't find RTC");
    Serial.flush();
    while (1) delay(10);
  }
  if (rtc.lostPower()) {
    Serial.println("RTC lost power, let's set the time!");
    rtc.adjust(DateTime(F(__DATE__), F(__TIME__)));
  }
  //*****time adjust*****time adjust*****time adjust*****time adjust*****time adjust*****time adjust
  //rtc.adjust(DateTime(F(__DATE__), F(__TIME__))); //Set time automatically. Upload the code once with this
                                                     //line and then remove it and upload again.
                                                     
  //rtc.adjust(DateTime(2014, 1, 21, 3, 0, 0));     //Set time manually. year, month, day, hour, min, sec. Upload the 
                                                    //code once with this line and then remove it and upload again.
  //*****time adjust*****time adjust*****time adjust*****time adjust*****time adjust*****time adjust

  FastLED.addLeds<WS2812, LED_PIN, GRB>(leds, NUM_LEDS);
  off();
  delay(1000);
  
  //*****start sequence*****start sequence*****start sequence*****start sequence
  red = start_red; green = start_green; blue = start_blue;
  for (int i = 0; i <= 57; i++) {
    leds[i] = CRGB (red, green, blue);
    FastLED.show();
    delay(65);
  }
  for (int i = 0; i <= 57; i++) {
    leds[i] = CRGB ( 0, 0, 0);
    FastLED.show();
    delay(65);
  }
  //*****start sequence*****start sequence*****start sequence*****start sequence
  
  off();
  leds[28] = CRGB (0, 0, 0);
  leds[29] = CRGB (0, 0, 0);
  FastLED.show();

  pinMode(A1, INPUT);
}

void loop () {
  
  DateTime now = rtc.now();
  h = now.hour();
  m = now.minute();
  //if(h > 12)h = h - 12; //Insert this line, if you want to use the 12 hour format
  hv = h / 10;
  hh = h % 10;
  mv = m / 10;
  mh = m % 10;

  //*****LDR sensor*****LDR sensor*****LDR sensor*****
  messwert = analogRead(A1);
  if(messwert > switch_to_day && z == 0)z = 1;
  if(messwert < switch_to_night && z == 1)z = 0;
  if(z == 0){red = night_red; green = night_green; blue = night_blue;}
  if(z == 1){red = day_red; green = day_green; blue = day_blue;}
  //*****LDR sensor*****LDR sensor*****LDR sensor*****
  
  leds[28] = CRGB (red, green, blue);
  leds[29] = CRGB (red, green, blue);
  FastLED.show();  

  if (h >= 10){
   number(1, mh);
   number(2, mv);
   number(3, hh);
   number(4, hv);  
  }
  if (h < 10){
   number(1, mh);
   number(2, mv);
   number(3, hh);
   number(4, 100);  
  }
  delay(100);
}

void off(){
  for(int k = 0; k <= 57; k++){
    if(k == 28) k = 30;
    leds[k] = CRGB (0, 0, 0); 
  }
  FastLED.show();
}

void number(int stelle, int ziffer){
 int fakstelle = 0;
 switch (stelle){
  case 1:
  fakstelle = 0;
  break;
  case 2:
  fakstelle = 14;
  break;
  case 3:
  fakstelle = 30;
  break;
  case 4:
  fakstelle = 44;
  break;
 }

 switch (ziffer){
   case 0:
    for(int k = 0; k <= 13; k++){ 
    int h = k + fakstelle;
    leds[h] = CRGB (red, green, blue); 
    if (k == 6 || k == 7) leds[h] = CRGB (0, 0, 0);
    }
   break;
   case 1:
    for(int k = 0; k <= 13; k++){
    int h = k + fakstelle;
    leds[h] = CRGB (0, 0, 0);    
    if(k == 0 || k == 1 || k == 8 || k == 9) leds[h] = CRGB (red, green, blue); 
    }
   break;
   case 2:
    for(int k = 0; k <= 13; k++){ 
    int h = k + fakstelle;
    leds[h] = CRGB (red, green, blue);
    if(k == 0 || k == 1 || k == 12 || k == 13) leds[h] = CRGB (0, 0, 0);    
    }
   break;
   case 3:
    for(int k = 0; k <= 13; k++){
    int h = k + fakstelle;
    leds[h] = CRGB (red, green, blue);
    if(k == 4 || k == 5 || k == 12 || k == 13) leds[h] = CRGB (0, 0, 0);  
    }
   break;
   case 4:
    for(int k = 0; k <= 13; k++){
    int h = k + fakstelle;
    leds[h] = CRGB (red, green, blue);
    if(k == 2 || k == 3 || k == 4 || k == 5 || k == 10 || k == 11) leds[h] = CRGB (0, 0, 0);  
    }
   break;
   case 5:
    for(int k = 0; k <= 13; k++){ 
    int h = k + fakstelle;
    leds[h] = CRGB (red, green, blue);
    if(k == 4 || k == 5 || k == 8 || k == 9) leds[h] = CRGB (0, 0, 0);
    }
   break;
   case 6:
    for(int k = 0; k <= 13; k++){ 
    int h = k + fakstelle;
    leds[h] = CRGB (red, green, blue);
    if(k == 8 || k == 9) leds[h] = CRGB (0, 0, 0); 
    }
   break;
   case 7:
    for(int k = 0; k <= 13; k++){
    int h = k + fakstelle;
    leds[h] = CRGB (0, 0, 0);    
    if(k == 0 || k == 1 || k == 8 || k == 9 || k == 10 || k == 11) leds[h] = CRGB (red, green, blue); 
    }
   break;
   case 8:
    for(int k = 0; k <= 13; k++){
    int h = k + fakstelle;
    leds[h] = CRGB (red, green, blue); 
    }
   break;
   case 9:
    for(int k = 0; k <= 13; k++){
    int h = k + fakstelle;
    leds[h] = CRGB (red, green, blue);
    if(k == 4 || k == 5) leds[h] = CRGB (0, 0, 0); 
    }
   break;
   case 100:
    for(int k = 0; k <= 13; k++){
    int h = k + fakstelle;
    leds[h] = CRGB (0, 0, 0); 
    }
   break;
 }
 FastLED.show();
}
